@@ -36,7 +36,15 @@
 
 """
 
-__version__ = "1.4.3"
+__author__ = "Michael G. Noll"
+__copyright__ = "(c) 2006-2008 Michael G. Noll"
+__description__ = "Unofficial Python API for retrieving data from del.icio.us"
+__email__ = "coding[AT]michael-REMOVEME-noll[DOT]com"
+__license__ = "GPLv2"
+__maintainer__ = "Michael G. Noll"
+__status__ = "Development"
+__url__ = "http://www.michael-noll.com/"
+__version__ = "1.4.5"
 
 import base64
 import cgi
@@ -138,8 +146,9 @@ class DeliciousURL(object):
             A list of (user, tags, timestamp tuples), representing a document's
             bookmark history.
 
-            user is a 'str', tags is a 'list', timestamp is a 'str' in
-            'YYYY-MM' format
+            user is a 'unicode'
+            tags is a 'list' of 'unicode's
+            timestamp is a 'datetime.datetime' (only YYYY-MM granularity)
 
         tags (read-only property):
             A list of (tag, tag_count) tuples, aggregated over all a document's
@@ -228,7 +237,8 @@ class DeliciousAPI(object):
                 download a monitored document. wait_seconds must be >= 0.
                 See also tries.
 
-            user_agent (optional, default: "Mozilla/4.0 (compatible; research)")
+            user_agent (optional, default: "DeliciousAPI/<version> \
+                    (+http://www.michael-noll.com/wiki/Del.icio.us_Python_API)")
                 Set the User-Agent HTTP Header.
 
             timeout (optional, default: 30):
@@ -394,10 +404,8 @@ class DeliciousAPI(object):
                         for user_tag_a in user_tags_a:
                             if user_tag_a.contents:
                                 user_tags.append(user_tag_a.contents[0])
-                        timestamp_string = ""
-                        if timestamp:
-                            timestamp_string = timestamp.strftime('%Y-%m')
-                        bookmarks.append( (user, user_tags, timestamp_string) )
+                        bookmarks.append( (user, user_tags, timestamp) )
+                        timestamp = None
         # put old bookmarks to the beginning, and new to the end
         bookmarks.reverse()
         return bookmarks
@@ -479,7 +487,7 @@ class DeliciousAPI(object):
             # the user's RSS feed. However, the feed is restricted
             # to the most recent public bookmarks of the user (about 30
             # if any)
-            path = "/rss/%s" % username
+            path = "/rss/%s?count=100" % username
             data = self._query(path, host="feeds.delicious.com", user=username)
             if data:
                 f = feedparser.parse(data)
@@ -490,8 +498,14 @@ class DeliciousAPI(object):
                         tags = entry.tags[0].term.split()
                     else:
                         tags.append(u"system:unfiled")
-                    title = entry.title
-                    notes = entry.summary
+                    try:
+                        title = entry.title
+                    except AttributeError:
+                        title = ""
+                    try:
+                        notes = entry.summary
+                    except AttributeError:
+                        notes = ""
                     timestamp = datetime.datetime.strptime(entry.updated, "%Y-%m-%dT%H:%M:%SZ")
                     bookmarks.append( (url, tags, title, notes, timestamp) )
                 user.bookmarks = bookmarks
